unit PingLogging;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Ping, Spin, Buttons, ExtCtrls, inifiles, ComCtrls;

type
  TForm1 = class(TForm)
    Ping1: TPing;
    HostName: TEdit;
    Label1: TLabel;
    Timer1: TTimer;
    GroupBox1: TGroupBox;
    buttonStart: TBitBtn;
    Interval: TSpinEdit;
    buttonPause: TBitBtn;
    GroupBox2: TGroupBox;
    Button1: TButton;
    Button2: TButton;
    GroupBox3: TGroupBox;
    Label4: TLabel;
    LogFileName: TEdit;
    SpeedButton1: TSpeedButton;
    cbErrors: TCheckBox;
    cbMaxPing: TCheckBox;
    cbDNS: TCheckBox;
    cbAll: TCheckBox;
    MaxPingTime: TSpinEdit;
    Label3: TLabel;
    OpenDialog1: TOpenDialog;
    Label5: TLabel;
    rbMinutes: TRadioButton;
    rbSeconds: TRadioButton;
    DisplayMemo: TRichEdit;
    procedure Button1Click(Sender: TObject);
    procedure Ping1DnsLookupDone(Sender: TObject; Error: Word);
    procedure Ping1EchoReply(Sender, Icmp: TObject; Error: Integer);
    procedure Ping1EchoRequest(Sender, Icmp: TObject);
    procedure buttonPauseClick(Sender: TObject);
    procedure buttonStartClick(Sender: TObject);
    procedure Timer1Timer(Sender: TObject);
    procedure SpeedButton1Click(Sender: TObject);
    procedure OutputLines(lines: string; MsgType: string);
    procedure cbAllClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1   : TForm1;
  IniFile : TIniFile;
  FileHandle : TextFile;

implementation

{$R *.DFM}

procedure TForm1.Button1Click(Sender: TObject);
begin
    OutputLines('-----', 'All');
    OutputLines(DateTimeToStr(Now), 'All');
    OutputLines('Resolving host ''' + HostName.Text + '''', 'All');
    Ping1.DnsLookup(trim(HostName.Text));
end;

procedure TForm1.Ping1DnsLookupDone(Sender: TObject; Error: Word);
begin
    if Error <> 0 then begin
        OutputLines('Unknown Host ''' + HostName.Text + '''', 'DNS');
        Exit;
    end;

    OutputLines('Host ''' + HostName.Text + ''' is ' + Ping1.DnsResult, 'All');
    Ping1.Address := Ping1.DnsResult;
    Ping1.Ping;

end;

procedure TForm1.Ping1EchoReply(Sender, Icmp: TObject; Error: Integer);
begin
    if Error = 0 then
        OutputLines('Cannot ping host (' + Ping1.HostIP + ') : ' +
                              Ping1.ErrorString, 'Error')
    else
    begin
       if (Ping1.Reply.RTT > MaxPingTime.Value) then  // Ping Times Exceed Max
           OutputLines('Received ' + IntToStr(Ping1.Reply.DataSize) +
                              ' bytes from ' + Ping1.HostIP +
                              ' in ' + IntToStr(Ping1.Reply.RTT) + ' msecs', 'Ping')
       else
           OutputLines('Received ' + IntToStr(Ping1.Reply.DataSize) +
                              ' bytes from ' + Ping1.HostIP +
                              ' in ' + IntToStr(Ping1.Reply.RTT) + ' msecs', 'All');
    end;
end;

procedure TForm1.Ping1EchoRequest(Sender, Icmp: TObject);
begin
    OutputLines('Sending ' + IntToStr(Ping1.Size) + ' bytes to ' +
                          Ping1.HostName + ' (' + Ping1.HostIP + ')', 'All');

end;

procedure TForm1.buttonPauseClick(Sender: TObject);
begin
   Timer1.Enabled      := False;
   buttonStart.Enabled := True;
   buttonPause.Enabled := False;
   rbMinutes.Enabled   := True;
   rbSeconds.Enabled   := True;
   Interval.Enabled    := True;
end;

procedure TForm1.buttonStartClick(Sender: TObject);
begin
   if rbMinutes.checked then
      Timer1.Interval := Interval.Value * 60000
   else
      Timer1.Interval := Interval.Value * 1000;

   Timer1.Enabled      := True;
   buttonPause.Enabled := True;
   buttonStart.Enabled := False;
   rbMinutes.Enabled   := False;
   rbSeconds.Enabled   := False;
   Interval.Enabled    := False;

end;

procedure TForm1.Timer1Timer(Sender: TObject);
begin
   Button1.Click;
end;

procedure TForm1.SpeedButton1Click(Sender: TObject);
begin
   OpenDialog1.Execute;
   LogFileName.Text := OpenDialog1.FileName;
end;

procedure TForm1.OutputLines(lines: string; MsgType: string);
var
   LogIt: Boolean;
begin

   // Open/Create File For Writing
   AssignFile(FileHandle, LogFileName.Text);
   if FileExists(LogFileName.Text) then
      Append(FileHandle)
   else Rewrite(FileHandle);

   // Determine if We Are To Log It
   LogIt := False;
   if ((MsgType = 'Error') and (cbErrors.Checked)) then  // Misc. Error
   begin
      LogIt := True;
      DisplayMemo.SelAttributes.Color := clRed;
      DisplayMemo.SelAttributes.Style := [fsBold];
   end;
   if ((MsgType = 'DNS')   and (cbDNS.Checked))    then  // DNS Error
   begin
      LogIt := True;
      DisplayMemo.SelAttributes.Color := clRed;
      DisplayMemo.SelAttributes.Style := [fsItalic];
   end;
   if ((MsgType = 'Ping')  and (cbMaxPing.Checked))then  // Ping Error
   begin
      LogIt := True;
      DisplayMemo.SelAttributes.Color := clRed;
      DisplayMemo.SelAttributes.Style := [fsUnderline];
   end;
   if (cbAll.Checked)      then LogIt := True;           // Log Everything

   // Write Information & Echo to Screen
   if LogIt = True then
   begin
      Writeln(FileHandle, lines);
      DisplayMemo.Lines.Add(lines);
      DisplayMemo.SelAttributes.Color := clBlack;
      DisplayMemo.SelAttributes.Style := [];
   end;

   // Close The File
   CloseFile(FileHandle);
end;

procedure TForm1.cbAllClick(Sender: TObject);
begin
   If cbAll.Checked then
   begin
      cbErrors.Checked  := True;
      cbMaxPing.Checked := True;
      cbDNS.Checked     := True;
      cbErrors.Enabled  := False;
      cbMaxPing.Enabled := False;
      cbDNS.Enabled     := False;
   end
   else
   begin
      cbErrors.Checked  := False;
      cbMaxPing.Checked := False;
      cbDNS.Checked     := False;
      cbErrors.Enabled  := True;
      cbMaxPing.Enabled := True;
      cbDNS.Enabled     := True;
   end;

end;

end.
